@@ -24,6 +24,7 @@ use autodie;
 
 use Path::Tiny;
 
+use Lintian::Index::Item;
 use Lintian::Index::Orig;
 
 use Moo::Role;
@@ -71,8 +72,6 @@ NB: If sorted_index includes a debian packaging, it is was
 contained in upstream part of the source package (or the package is
 native).
 
-Needs-Info requirements for using I<orig_index>: src-orig-index
-
 =cut
 
 sub orig_index {
@@ -94,17 +93,15 @@ sub sorted_orig_index {
 =item orig_index_resolved_path(PATH)
 
 Resolve PATH (relative to the root of the package) and return the
-L<entry|Lintian::File::Path> denoting the resolved path.
+L<entry|Lintian::Index::Item> denoting the resolved path.
 
 The resolution is done using
-L<resolve_path|Lintian::File::Path/resolve_path([PATH])>.
+L<resolve_path|Lintian::Index::Item/resolve_path([PATH])>.
 
 NB: If orig_index_resolved_path includes a debian packaging, it is was
 contained in upstream part of the source package (or the package is
 native).
 
-Needs-Info requirements for using I<orig_index_resolved_path>: L<Same as orig_index|/orig_index (FILE)>
-
 =cut
 
 sub orig_index_resolved_path {
